@@ -369,7 +369,8 @@ class ATranspiler:
         self.print_format_string_next_id = 0
         self.print_max_num_args = 0
         self.has_exit_event = False
-        self.events = {}
+        self.events_in = {}  # @onevent
+        self.events_out = {}  # emit
 
     @staticmethod
     def decode_attr(node):
@@ -403,8 +404,6 @@ class ATranspiler:
                 if node.name in parent_context.functions:
                     raise TranspilerError(f"function '{node.name}' defined multiple times", ast_node=node)
                 if len(node.args.args) > 0:
-                    if is_onevent:
-                        raise TranspilerError(f"unexpected arguments in @onevent function '{node.name}'", ast_node=node)
                     if len(node.args.defaults) > 0:
                         raise TranspilerError(f"unsupported default values for arguments of '{node.name}'", ast_node=node)
                     if len({a.arg for a in node.args.args}) < len(node.args.args):
@@ -877,11 +876,11 @@ end
                         raise TranspilerError("bad event name in emit", node)
                     event_name = expr.args[0].value
                     event_size = len(expr.args) - 1
-                    if event_name in self.events:
-                        if event_size != self.events[event_name]:
+                    if event_name in self.events_out:
+                        if event_size != self.events_out[event_name]:
                             raise TranspilerError(f"inconsistent size for event '{event_name}'", node)
                     else:
-                        self.events[event_name] = event_size
+                        self.events_out[event_name] = event_size
                     code = f"emit {event_name}"
                     aux_statements = ""
                     if len(expr.args) > 1:
@@ -912,7 +911,7 @@ end
                     aux_statements = ""
                     for i, arg in enumerate(expr.args):
                         if isinstance(arg, ast.Constant) and isinstance(arg.value, str):
-                            print_format_string += (" " if i > 0 else "") + arg.value
+                            print_format_string += (" " if i > 0 else "") + arg.value.replace("%", "%%")
                         else:
                             value, aux_st, _ = self.compile_expr(arg, context, self.PRI_NUMERIC)
                             aux_statements += aux_st
@@ -1140,10 +1139,15 @@ return
             self.reset_transpile_phase(fun_print_format_string_next_id)
         # second pass to produce transpiled code with correct local variable names
         for fun_name in context_top.functions:
-            fun_output_src = self.compile_node_array(context_top.functions[fun_name].function_def.body, context_top.functions[fun_name])
-            if context_top.functions[fun_name].is_onevent:
+            function = context_top.functions[fun_name]
+            fun_output_src = self.compile_node_array(function.function_def.body, function)
+            if function.is_onevent:
+                self.events_in[fun_name] = len(function.function_def.args.args)
                 function_src += f"""
 onevent {fun_name.replace("_", ".")}
+"""
+                for i, arg in enumerate(function.function_def.args.args):
+                    function_src += f"""{function.var_str(arg.arg, True)} = event.args[{i}]
 """
             else:
                 function_src += f"""
@@ -1217,10 +1221,17 @@ sub {fun_name}
         return self.pretty_print(self.output_src)
 
     @staticmethod
-    def simple_transpile(input_src, modules=None, preamble=None):
+    def simple_transpile(input_src,
+                         modules="thymio",
+                         preamble="from thymio import *\n"):
         """Transpile program from python to aseba, returning the aseba source code.
         """
         transpiler = ATranspiler()
+        if modules == "thymio":
+            from tdmclient.module_thymio import ModuleThymio
+            modules = {
+                "thymio": ModuleThymio()
+            }
         if modules is not None:
             transpiler.modules = {**transpiler.modules, **modules}
         if preamble is not None:
