@@ -141,6 +141,18 @@ class TDMConsole(code.InteractiveConsole):
             """
             return self.get_event_data(event_name)
 
+        def send_event(event_name, *args):
+            """Send a custom event to the robot. Arguments can be numbers,
+            booleans and/or arrays.
+            """
+            # flatten args
+            data = [
+                item
+                for arg in args
+                for item in (arg if isinstance(arg, list) else [arg])
+            ]
+            self.node.send_send_events({event_name: data})
+
         self.functions = {
             "onevent": onevent,
             "sleep": sleep,
@@ -150,6 +162,7 @@ class TDMConsole(code.InteractiveConsole):
             "stop": stop,
             "clear_event_data": clear_event_data,
             "get_event_data": get_event_data,
+            "send_event": send_event,
         }
 
         if local_var is None:
@@ -240,8 +253,10 @@ class TDMConsole(code.InteractiveConsole):
                 events.append(("_print", 1 + transpiler.print_max_num_args))
             if transpiler.has_exit_event:
                 events.append(("_exit", 1))
-            for event_name in transpiler.events:
-                events.append((event_name, transpiler.events[event_name]))
+            for event_name in transpiler.events_in:
+                events.append((event_name, transpiler.events_in[event_name]))
+            for event_name in transpiler.events_out:
+                events.append((event_name, transpiler.events_out[event_name]))
             if len(events) > 0:
                 ClientAsync.aw(self.node.register_events(events))
         elif language != "aseba":
