@@ -178,8 +178,10 @@ if __name__ == "__main__":
             events.append(("_print", 1 + transpiler.print_max_num_args))
         if transpiler.has_exit_event:
             events.append(("_exit", 1))
-        for event_name in transpiler.events:
-            events.append((event_name, transpiler.events[event_name]))
+        for event_name in transpiler.events_in:
+            events.append((event_name, transpiler.events_in[event_name]))
+        for event_name in transpiler.events_out:
+            events.append((event_name, transpiler.events_out[event_name]))
 
     if sleep is None:
         sleep = len(events) > 0
